pub struct Args {
pub cpu: bool,
pub tracing: bool,
pub model_id: Option<String>,
pub revision: Option<String>,
pub use_pth: bool,
pub normalize_embeddings: bool,
pub approximate_gelu: bool,
}Fields
cpu: boolRun on CPU rather than on GPU.
tracing: boolEnable tracing (generates a trace-timestamp.json file).
model_id: Option<String>The model to use, check out available models: https://huggingface.co/models?library=sentence-transformers&sort=trending
revision: Option<String>use_pth: boolUse the pytorch weights rather than the safetensors ones
normalize_embeddings: boolL2 normalization for embeddings.
approximate_gelu: boolUse tanh based approximation for Gelu instead of erf implementation.
Implementations